=========
Changelog
=========

Version 0.4
===========

* Use `actions/checkout@v3` instead of V2 due to deprecation of Node12 with Github actions

Version 0.3
===========

* Change some things for demo purposes 
* Bumped version number in pyproject.toml
* Added note to README to make sure version number was also bumped in `pyproject.toml`

Version 0.2
===========

* Testing a new tag
* Fixed tag and release

Version 0.1
===========

* Project skeleton created.
* `tox.ini` file created. Workflows should work now. 
	* Fix `tox.ini`. It should now have the build environment. 
* Comment out twine check, checking for correct rendering on PyPI